CustomShimmer class

A widget that applies a shimmer effect to its child

Inheritance

Constructors

CustomShimmer({Key? key, required Widget child, Color? baseColor, Color? highlightColor, ShimmerDirection direction = ShimmerDirection.ltr, Duration duration = const Duration(milliseconds: 1500), bool enabled = true, int? loop})
const

Properties

baseColor Color?
Optional base color for the shimmer effect
final
child Widget
The widget to apply the shimmer effect to
final
direction → ShimmerDirection
Optional direction for the shimmer effect
final
duration Duration
Optional duration for the shimmer animation
final
enabled bool
Optional enable state for the shimmer
final
hashCode int
The hash code for this object.
no setterinherited
highlightColor Color?
Optional highlight color for the shimmer effect
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
loop int?
Optional loop count for the shimmer animation (null means infinite)
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

build(BuildContext context) Widget
Describes the part of the user interface represented by this widget.
override
createElement() StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

avatar({double size = 48, BorderRadius? borderRadius}) Widget
Create a shimmer avatar
card({double width = double.infinity, double height = 200, double borderRadius = 12.0}) Widget
Create a shimmer card
grid({int crossAxisCount = 2, int itemCount = 4, double itemHeight = 120, double spacing = 16.0, double borderRadius = 8.0}) Widget
Create a shimmer grid
list({int itemCount = 3, double itemHeight = 80, double spacing = 16.0, double borderRadius = 8.0}) Widget
Create a shimmer list with multiple items
listItem({double width = double.infinity, double height = 80, double borderRadius = 8.0}) Widget
Create a shimmer list item for lists
text({double width = 200, double height = 16, double borderRadius = 4.0}) Widget
Create a shimmer text line