CustomButton class
A customizable button widget with various styles
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatelessWidget
- CustomButton
Constructors
- CustomButton({Key? key, required String text, required VoidCallback onPressed, ButtonType type = ButtonType.primary, IconData? icon, double? width, double height = 48.0, double borderRadius = 8.0, Color? backgroundColor, Color? textColor, Color? iconColor, bool isLoading = false, bool isDisabled = false, EdgeInsetsGeometry? padding, double fontSize = 16.0, FontWeight fontWeight = FontWeight.w600})
-
const
Properties
- backgroundColor → Color?
-
Optional background color (overrides the default for the button type)
final
- borderRadius → double
-
Optional border radius (defaults to rounded corners)
final
- fontSize → double
-
Optional font size
final
- fontWeight → FontWeight
-
Optional font weight
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- height → double
-
Optional height for the button (defaults to standard height)
final
- icon → IconData?
-
Optional icon to display before the text
final
- iconColor → Color?
-
Optional icon color (defaults to text color)
final
- isDisabled → bool
-
Optional disabled state
final
- isLoading → bool
-
Optional loading state to show a loading indicator instead of text
final
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- onPressed → VoidCallback
-
The function to call when the button is pressed
final
- padding → EdgeInsetsGeometry?
-
Optional custom padding
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- text → String
-
The text to display on the button
final
- textColor → Color?
-
Optional text color (overrides the default for the button type)
final
- type → ButtonType
-
The type of button to display
final
- width → double?
-
Optional width for the button (defaults to fit content)
final
Methods
-
build(
BuildContext context) → Widget -
Describes the part of the user interface represented by this widget.
override
-
createElement(
) → StatelessElement -
Creates a StatelessElement to manage this widget's location in the tree.
inherited
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited